@@ -1,32 +1,38 @@
 OC.L10N.register(
     "deck",
     {
-    "Personal" : "Perséinlech",
+    "In Progress" : "A Beaarbechtung",
     "Done" : "Done",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Déi ropgelueden Datei ass méi grouss wei d'MAX_FILE_SIZE Eegenschaft déi an der HTML form uginn ass",
     "No file was uploaded" : "Et ass kee Fichier ropgeluede ginn",
     "Missing a temporary folder" : "Et feelt en temporären Dossier",
     "Cancel" : "Ofbriechen",
-    "Close" : "Zoumaachen",
+    "Completed" : "Erfëllt",
     "Details" : "Detailer",
     "Sharing" : "Gedeelt",
     "Tags" : "Tags",
+    "Activity" : "Aktivitéit",
     "Can edit" : "Can edit",
     "Can share" : "Can share",
     "Owner" : "Owner",
     "Delete" : "Läschen",
     "Edit" : "Änneren",
     "Download" : "Eroflueden",
-    "Comments" : "Kommentarer",
     "Modified" : "Geännert",
-    "Today" : "Haut",
-    "Tomorrow" : "Muer",
+    "Comments" : "Kommentarer",
     "Save" : "Späicheren",
+    "Created:" : "Erstallt:",
     "Reply" : "Äntwerten",
     "Update" : "Update",
     "Description" : "Beschreiwung",
     "seconds ago" : "Sekonnen hier",
+    "Search" : "Search",
     "Shared with you" : "Mat dir gedeelt",
-    "Share" : "Deelen"
+    "Advanced options" : "Erweidert Astellungen",
+    "Today" : "Haut",
+    "Tomorrow" : "Muer",
+    "Close" : "Zoumaachen",
+    "Share" : "Deelen",
+    "Personal" : "Perséinlech"
 },
 "nplurals=2; plural=(n != 1);");
