@@ -1,118 +1,76 @@
 <?php
+
 /**
- * @copyright Copyright (c) 2016 Julius Härtl <jus@bitgrid.net>
- *
- * @author Julius Härtl <jus@bitgrid.net>
- * @author Maxence Lange <maxence@artificial-owl.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- *  This program is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU Affero General Public License as
- *  published by the Free Software Foundation, either version 3 of the
- *  License, or (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Affero General Public License for more details.
- *
- *  You should have received a copy of the GNU Affero General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Deck\Service;
 
-use Doctrine\DBAL\Exception\UniqueConstraintViolationException;
 use OCA\Deck\Activity\ActivityManager;
 use OCA\Deck\Activity\ChangeSet;
 use OCA\Deck\AppInfo\Application;
+use OCA\Deck\BadRequestException;
 use OCA\Deck\Db\Acl;
 use OCA\Deck\Db\AclMapper;
 use OCA\Deck\Db\AssignmentMapper;
+use OCA\Deck\Db\Board;
+use OCA\Deck\Db\BoardMapper;
+use OCA\Deck\Db\Card;
 use OCA\Deck\Db\CardMapper;
 use OCA\Deck\Db\ChangeHelper;
 use OCA\Deck\Db\IPermissionMapper;
 use OCA\Deck\Db\Label;
+use OCA\Deck\Db\LabelMapper;
+use OCA\Deck\Db\Session;
+use OCA\Deck\Db\SessionMapper;
 use OCA\Deck\Db\Stack;
 use OCA\Deck\Db\StackMapper;
 use OCA\Deck\Event\AclCreatedEvent;
 use OCA\Deck\Event\AclDeletedEvent;
 use OCA\Deck\Event\AclUpdatedEvent;
+use OCA\Deck\Event\BoardUpdatedEvent;
+use OCA\Deck\Event\CardCreatedEvent;
 use OCA\Deck\NoPermissionException;
 use OCA\Deck\Notification\NotificationHelper;
+use OCA\Deck\Validators\BoardServiceValidator;
 use OCP\AppFramework\Db\DoesNotExistException;
+use OCP\AppFramework\Db\MultipleObjectsReturnedException;
+use OCP\DB\Exception as DbException;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IConfig;
-use OCP\IGroupManager;
+use OCP\IDBConnection;
 use OCP\IL10N;
-use OCA\Deck\Db\Board;
-use OCA\Deck\Db\BoardMapper;
-use OCA\Deck\Db\LabelMapper;
-use OCP\IUserManager;
-use OCA\Deck\BadRequestException;
 use OCP\IURLGenerator;
+use OCP\Server;
+use Psr\Container\ContainerExceptionInterface;
+use Psr\Container\NotFoundExceptionInterface;
 
 class BoardService {
-	private $boardMapper;
-	private $stackMapper;
-	private $labelMapper;
-	private $aclMapper;
-	/** @var IConfig */
-	private $config;
-	private $l10n;
-	private $permissionService;
-	private $notificationHelper;
-	private $assignedUsersMapper;
-	private $userManager;
-	private $groupManager;
-	private $userId;
-	private $activityManager;
-	private $eventDispatcher;
-	private $changeHelper;
-	private $cardMapper;
-
-	private $boardsCache = null;
-	private $urlGenerator;
-
+	private ?array $boardsCacheFull = null;
+	private ?array $boardsCachePartial = null;
 
 	public function __construct(
-		BoardMapper $boardMapper,
-		StackMapper $stackMapper,
-		IConfig $config,
-		IL10N $l10n,
-		LabelMapper $labelMapper,
-		AclMapper $aclMapper,
-		PermissionService $permissionService,
-		NotificationHelper $notificationHelper,
-		AssignmentMapper $assignedUsersMapper,
-		CardMapper $cardMapper,
-		IUserManager $userManager,
-		IGroupManager $groupManager,
-		ActivityManager $activityManager,
-		IEventDispatcher $eventDispatcher,
-		ChangeHelper $changeHelper,
-		IURLGenerator $urlGenerator,
-		$userId
+		private BoardMapper $boardMapper,
+		private StackMapper $stackMapper,
+		private CardMapper $cardMapper,
+		private IConfig $config,
+		private IL10N $l10n,
+		private LabelMapper $labelMapper,
+		private AclMapper $aclMapper,
+		private PermissionService $permissionService,
+		private AssignmentService $assignmentService,
+		private NotificationHelper $notificationHelper,
+		private AssignmentMapper $assignedUsersMapper,
+		private ActivityManager $activityManager,
+		private IEventDispatcher $eventDispatcher,
+		private ChangeHelper $changeHelper,
+		private IURLGenerator $urlGenerator,
+		private IDBConnection $connection,
+		private BoardServiceValidator $boardServiceValidator,
+		private SessionMapper $sessionMapper,
+		private ?string $userId,
 	) {
-		$this->boardMapper = $boardMapper;
-		$this->stackMapper = $stackMapper;
-		$this->labelMapper = $labelMapper;
-		$this->config = $config;
-		$this->aclMapper = $aclMapper;
-		$this->l10n = $l10n;
-		$this->permissionService = $permissionService;
-		$this->notificationHelper = $notificationHelper;
-		$this->assignedUsersMapper = $assignedUsersMapper;
-		$this->userManager = $userManager;
-		$this->groupManager = $groupManager;
-		$this->activityManager = $activityManager;
-		$this->eventDispatcher = $eventDispatcher;
-		$this->changeHelper = $changeHelper;
-		$this->userId = $userId;
-		$this->urlGenerator = $urlGenerator;
-		$this->cardMapper = $cardMapper;
 	}
 
 	/**
@@ -122,118 +80,60 @@ class BoardService {
 	 */
 	public function setUserId(string $userId): void {
 		$this->userId = $userId;
+		$this->permissionService->setUserId($userId);
 	}
 
 	/**
 	 * Get all boards that are shared with a user, their groups or circles
 	 */
 	public function getUserBoards(?int $since = null, bool $includeArchived = true, ?int $before = null,
-								  ?string $term = null): array {
+		?string $term = null): array {
 		return $this->boardMapper->findAllForUser($this->userId, $since, $includeArchived, $before, $term);
 	}
 
 	/**
-	 * @return array
+	 * @return Board[]
 	 */
-	public function findAll($since = -1, $details = null, $includeArchived = true) {
-		if ($this->boardsCache) {
-			return $this->boardsCache;
-		}
+	public function findAll(int $since = -1, bool $fullDetails = false, bool $includeArchived = true): array {
 		$complete = $this->getUserBoards($since, $includeArchived);
-		$result = [];
-		/** @var Board $item */
-		foreach ($complete as &$item) {
-			$this->boardMapper->mapOwner($item);
-			if ($item->getAcl() !== null) {
-				foreach ($item->getAcl() as &$acl) {
-					$this->boardMapper->mapAcl($acl);
-				}
-			}
-			if ($details !== null) {
-				$this->enrichWithStacks($item);
-				$this->enrichWithLabels($item);
-				$this->enrichWithUsers($item);
-			}
-			$permissions = $this->permissionService->matchPermissions($item);
-			$item->setPermissions([
-				'PERMISSION_READ' => $permissions[Acl::PERMISSION_READ] ?? false,
-				'PERMISSION_EDIT' => $permissions[Acl::PERMISSION_EDIT] ?? false,
-				'PERMISSION_MANAGE' => $permissions[Acl::PERMISSION_MANAGE] ?? false,
-				'PERMISSION_SHARE' => $permissions[Acl::PERMISSION_SHARE] ?? false
-			]);
-			$this->enrichWithBoardSettings($item);
-			$result[$item->getId()] = $item;
-		}
-		$this->boardsCache = $result;
-		return array_values($result);
+		return $this->enrichBoards($complete, $fullDetails);
 	}
 
 	/**
-	 * @param $boardId
-	 * @return Board
 	 * @throws DoesNotExistException
-	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws NoPermissionException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
-	public function find($boardId) {
-		if ($this->boardsCache && isset($this->boardsCache[$boardId])) {
-			return $this->boardsCache[$boardId];
+	public function find(int $boardId, bool $fullDetails = true, bool $allowDeleted = false): Board {
+		$this->boardServiceValidator->check(compact('boardId'));
+
+		if (isset($this->boardsCacheFull[$boardId]) && $fullDetails) {
+			return $this->boardsCacheFull[$boardId];
 		}
-		if (is_numeric($boardId) === false) {
-			throw new BadRequestException('board id must be a number');
+
+		if (isset($this->boardsCachePartial[$boardId]) && !$fullDetails) {
+			return $this->boardsCachePartial[$boardId];
 		}
 
 		$this->permissionService->checkPermission($this->boardMapper, $boardId, Acl::PERMISSION_READ);
 		/** @var Board $board */
-		$board = $this->boardMapper->find($boardId, true, true);
-		$this->boardMapper->mapOwner($board);
-		if ($board->getAcl() !== null) {
-			foreach ($board->getAcl() as $acl) {
-				if ($acl !== null) {
-					$this->boardMapper->mapAcl($acl);
-				}
-			}
-		}
-		$permissions = $this->permissionService->matchPermissions($board);
-		$board->setPermissions([
-			'PERMISSION_READ' => $permissions[Acl::PERMISSION_READ] ?? false,
-			'PERMISSION_EDIT' => $permissions[Acl::PERMISSION_EDIT] ?? false,
-			'PERMISSION_MANAGE' => $permissions[Acl::PERMISSION_MANAGE] ?? false,
-			'PERMISSION_SHARE' => $permissions[Acl::PERMISSION_SHARE] ?? false
-		]);
-		$this->enrichWithUsers($board);
-		$this->enrichWithBoardSettings($board);
-		$this->boardsCache[$board->getId()] = $board;
+		$board = $this->boardMapper->find($boardId, true, true, $allowDeleted);
+		[$board] = $this->enrichBoards([$board], $fullDetails);
 		return $board;
 	}
 
-	/**
-	 * @return array
-	 */
-	private function getBoardPrerequisites() {
-		$groups = $this->groupManager->getUserGroupIds(
-			$this->userManager->get($this->userId)
-		);
-		return [
-			'user' => $this->userId,
-			'groups' => $groups
-		];
-	}
-
 	/**
 	 * @param $mapper
 	 * @param $id
 	 * @return bool
 	 * @throws DoesNotExistException
-	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws NoPermissionException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
 	public function isArchived($mapper, $id) {
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('id must be a number');
-		}
+		$this->boardServiceValidator->check(compact('id'));
 
 		try {
 			$boardId = $id;
@@ -255,18 +155,12 @@ class BoardService {
 	 * @param $id
 	 * @return bool
 	 * @throws DoesNotExistException
-	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws NoPermissionException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
 	public function isDeleted($mapper, $id) {
-		if ($mapper === false || $mapper === null) {
-			throw new BadRequestException('mapper must be provided');
-		}
-
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('id must be a number');
-		}
+		$this->boardServiceValidator->check(compact('mapper', 'id'));
 
 		try {
 			$boardId = $id;
@@ -292,17 +186,7 @@ class BoardService {
 	 * @throws BadRequestException
 	 */
 	public function create($title, $userId, $color) {
-		if ($title === false || $title === null) {
-			throw new BadRequestException('title must be provided');
-		}
-
-		if ($userId === false || $userId === null) {
-			throw new BadRequestException('userId must be provided');
-		}
-
-		if ($color === false || $color === null) {
-			throw new BadRequestException('color must be provided');
-		}
+		$this->boardServiceValidator->check(compact('title', 'userId', 'color'));
 
 		if (!$this->permissionService->canCreate()) {
 			throw new NoPermissionException('Creating boards has been disabled for your account.');
@@ -348,14 +232,12 @@ class BoardService {
 	 * @param $id
 	 * @return Board
 	 * @throws DoesNotExistException
-	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws NoPermissionException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
 	public function delete($id) {
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('board id must be a number');
-		}
+		$this->boardServiceValidator->check(compact('id'));
 
 		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_MANAGE);
 		$board = $this->find($id);
@@ -374,16 +256,14 @@ class BoardService {
 	 * @param $id
 	 * @return \OCP\AppFramework\Db\Entity
 	 * @throws DoesNotExistException
-	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws NoPermissionException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 */
 	public function deleteUndo($id) {
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('board id must be a number');
-		}
+		$this->boardServiceValidator->check(compact('id'));
 
 		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_MANAGE);
-		$board = $this->find($id);
+		$board = $this->find($id, allowDeleted: true);
 		$board->setDeletedAt(0);
 		$board = $this->boardMapper->update($board);
 		$this->activityManager->triggerEvent(ActivityManager::DECK_OBJECT_BOARD, $board, ActivityManager::SUBJECT_BOARD_RESTORE);
@@ -396,17 +276,15 @@ class BoardService {
 	 * @param $id
 	 * @return \OCP\AppFramework\Db\Entity
 	 * @throws DoesNotExistException
-	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws NoPermissionException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
 	public function deleteForce($id) {
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('id must be a number');
-		}
+		$this->boardServiceValidator->check(compact('id'));
 
 		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_MANAGE);
-		$board = $this->find($id);
+		$board = $this->find($id, allowDeleted: true);
 		$delete = $this->boardMapper->delete($board);
 
 		return $delete;
@@ -419,26 +297,12 @@ class BoardService {
 	 * @param $archived
 	 * @return \OCP\AppFramework\Db\Entity
 	 * @throws DoesNotExistException
-	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws NoPermissionException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
 	public function update($id, $title, $color, $archived) {
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('board id must be a number');
-		}
-
-		if ($title === false || $title === null) {
-			throw new BadRequestException('title must be provided');
-		}
-
-		if ($color === false || $color === null) {
-			throw new BadRequestException('color must be provided');
-		}
-
-		if (is_bool($archived) === false) {
-			throw new BadRequestException('archived must be a boolean');
-		}
+		$this->boardServiceValidator->check(compact('id', 'title', 'color', 'archived'));
 
 		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_MANAGE);
 		$board = $this->find($id);
@@ -451,6 +315,7 @@ class BoardService {
 		$this->boardMapper->mapOwner($board);
 		$this->activityManager->triggerUpdateEvents(ActivityManager::DECK_OBJECT_BOARD, $changes, ActivityManager::SUBJECT_BOARD_UPDATE);
 		$this->changeHelper->boardChanged($board->getId());
+		$this->eventDispatcher->dispatchTyped(new BoardUpdatedEvent($board->getId()));
 
 		return $board;
 	}
@@ -476,6 +341,18 @@ class BoardService {
 		$board->setSettings($settings);
 	}
 
+	public function enrichWithActiveSessions(Board $board) {
+		$sessions = $this->sessionMapper->findAllActive($board->getId());
+
+		$board->setActiveSessions(array_values(
+			array_unique(
+				array_map(function (Session $session) {
+					return $session->getUserId();
+				}, $sessions)
+			)
+		));
+	}
+
 	/**
 	 * @param $boardId
 	 * @param $type
@@ -485,32 +362,10 @@ class BoardService {
 	 * @param $manage
 	 * @return \OCP\AppFramework\Db\Entity
 	 * @throws BadRequestException
-	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws NoPermissionException
 	 */
 	public function addAcl($boardId, $type, $participant, $edit, $share, $manage) {
-		if (is_numeric($boardId) === false) {
-			throw new BadRequestException('board id must be a number');
-		}
-
-		if ($type === false || $type === null) {
-			throw new BadRequestException('type must be provided');
-		}
-
-		if ($participant === false || $participant === null) {
-			throw new BadRequestException('participant must be provided');
-		}
-
-		if ($edit === null) {
-			throw new BadRequestException('edit must be provided');
-		}
-
-		if ($share === null) {
-			throw new BadRequestException('share must be provided');
-		}
-
-		if ($manage === null) {
-			throw new BadRequestException('manage must be provided');
-		}
+		$this->boardServiceValidator->check(compact('boardId', 'type', 'participant', 'edit', 'share', 'manage'));
 
 		$this->permissionService->checkPermission($this->boardMapper, $boardId, Acl::PERMISSION_SHARE);
 		[$edit, $share, $manage] = $this->applyPermissions($boardId, $edit, $share, $manage);
@@ -525,7 +380,7 @@ class BoardService {
 		$newAcl = $this->aclMapper->insert($acl);
 
 		$this->activityManager->triggerEvent(ActivityManager::DECK_OBJECT_BOARD, $newAcl, ActivityManager::SUBJECT_BOARD_SHARE, [], $this->userId);
-		$this->notificationHelper->sendBoardShared((int)$boardId, $acl);
+		$this->notificationHelper->sendBoardShared($boardId, $acl);
 		$this->boardMapper->mapAcl($newAcl);
 		$this->changeHelper->boardChanged($boardId);
 
@@ -534,7 +389,7 @@ class BoardService {
 
 		// TODO: use the dispatched event for this
 		try {
-			$resourceProvider = \OC::$server->query(\OCA\Deck\Collaboration\Resources\ResourceProvider::class);
+			$resourceProvider = Server::get(\OCA\Deck\Collaboration\Resources\ResourceProvider::class);
 			$resourceProvider->invalidateAccessCache($boardId);
 		} catch (\Exception $e) {
 		}
@@ -551,26 +406,12 @@ class BoardService {
 	 * @param $manage
 	 * @return \OCP\AppFramework\Db\Entity
 	 * @throws DoesNotExistException
-	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws NoPermissionException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
 	public function updateAcl($id, $edit, $share, $manage) {
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('id must be a number');
-		}
-
-		if ($edit === null) {
-			throw new BadRequestException('edit must be provided');
-		}
-
-		if ($share === null) {
-			throw new BadRequestException('share must be provided');
-		}
-
-		if ($manage === null) {
-			throw new BadRequestException('manage must be provided');
-		}
+		$this->boardServiceValidator->check(compact('id', 'edit', 'share', 'manage'));
 
 		$this->permissionService->checkPermission($this->aclMapper, $id, Acl::PERMISSION_SHARE);
 
@@ -590,27 +431,20 @@ class BoardService {
 	}
 
 	/**
-	 * @param $id
-	 * @return \OCP\AppFramework\Db\Entity
+	 * @throws DbException
 	 * @throws DoesNotExistException
-	 * @throws \OCA\Deck\NoPermissionException
-	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
-	 * @throws BadRequestException
+	 * @throws NoPermissionException
+	 * @throws MultipleObjectsReturnedException
+	 * @throws ContainerExceptionInterface
+	 * @throws NotFoundExceptionInterface
 	 */
-	public function deleteAcl($id) {
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('id must be a number');
-		}
-
+	public function deleteAcl(int $id): ?Acl {
 		$this->permissionService->checkPermission($this->aclMapper, $id, Acl::PERMISSION_SHARE);
 		/** @var Acl $acl */
 		$acl = $this->aclMapper->find($id);
 		$this->boardMapper->mapAcl($acl);
 		if ($acl->getType() === Acl::PERMISSION_TYPE_USER) {
-			$assignements = $this->assignedUsersMapper->findByParticipant($acl->getParticipant());
-			foreach ($assignements as $assignement) {
-				$this->assignedUsersMapper->delete($assignement);
-			}
+			$this->assignedUsersMapper->deleteByParticipantOnBoard($acl->getParticipant(), $acl->getBoardId());
 		}
 
 		$this->activityManager->triggerEvent(ActivityManager::DECK_OBJECT_BOARD, $acl, ActivityManager::SUBJECT_BOARD_UNSHARE);
@@ -620,30 +454,33 @@ class BoardService {
 		$version = \OCP\Util::getVersion()[0];
 		if ($version >= 16) {
 			try {
-				$resourceProvider = \OC::$server->query(\OCA\Deck\Collaboration\Resources\ResourceProvider::class);
+				$resourceProvider = Server::get(\OCA\Deck\Collaboration\Resources\ResourceProvider::class);
 				$resourceProvider->invalidateAccessCache($acl->getBoardId());
 			} catch (\Exception $e) {
 			}
 		}
-		$delete = $this->aclMapper->delete($acl);
 
+		$deletedAcl = $this->aclMapper->delete($acl);
 		$this->eventDispatcher->dispatchTyped(new AclDeletedEvent($acl));
 
-		return $delete;
+		return $deletedAcl;
 	}
 
 	/**
-	 * @param $id
-	 * @param $userId
-	 * @return Board
-	 * @throws DoesNotExistException
-	 * @throws \OCA\Deck\NoPermissionException
-	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
+	 * @throws DbException
+	 * @throws DoesNotExistException
+	 * @throws MultipleObjectsReturnedException
+	 * @throws NoPermissionException
 	 */
-	public function clone($id, $userId) {
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('board id must be a number');
+	public function clone(
+		int $id, string $userId,
+		bool $withCards = false, bool $withAssignments = false, bool $withLabels = false, bool $withDueDate = false, bool $moveCardsToLeftStack = false, bool $restoreArchivedCards = false,
+	): Board {
+		$this->boardServiceValidator->check(compact('id', 'userId'));
+
+		if (!$this->permissionService->canCreate()) {
+			throw new NoPermissionException('Creating boards has been disabled for your account.');
 		}
 
 		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_READ);
@@ -662,6 +499,16 @@ class BoardService {
 		]);
 		$this->boardMapper->insert($newBoard);
 
+		foreach ($this->aclMapper->findAll($board->getId()) as $acl) {
+			$this->addAcl($newBoard->getId(),
+				$acl->getType(),
+				$acl->getParticipant(),
+				$acl->getPermissionEdit(),
+				$acl->getPermissionShare(),
+				$acl->getPermissionManage());
+		}
+
+
 		$labels = $this->labelMapper->findAll($id);
 		foreach ($labels as $label) {
 			$newLabel = new Label();
@@ -675,15 +522,24 @@ class BoardService {
 		foreach ($stacks as $stack) {
 			$newStack = new Stack();
 			$newStack->setTitle($stack->getTitle());
+			if ($stack->getOrder() == null) {
+				$newStack->setOrder(999);
+			} else {
+				$newStack->setOrder($stack->getOrder());
+			}
 			$newStack->setBoardId($newBoard->getId());
 			$this->stackMapper->insert($newStack);
 		}
 
+		if ($withCards) {
+			$this->cloneCards($board, $newBoard, $withAssignments, $withLabels, $withDueDate, $moveCardsToLeftStack, $restoreArchivedCards);
+		}
+
 		return $this->find($newBoard->getId());
 	}
 
 	public function transferBoardOwnership(int $boardId, string $newOwner, bool $changeContent = false): Board {
-		\OC::$server->getDatabaseConnection()->beginTransaction();
+		$this->connection->beginTransaction();
 		try {
 			$board = $this->boardMapper->find($boardId);
 			$previousOwner = $board->getOwner();
@@ -692,7 +548,10 @@ class BoardService {
 			if (!$changeContent) {
 				try {
 					$this->addAcl($boardId, Acl::PERMISSION_TYPE_USER, $previousOwner, true, true, true);
-				} catch (UniqueConstraintViolationException $e) {
+				} catch (DbException $e) {
+					if ($e->getReason() !== DbException::REASON_UNIQUE_CONSTRAINT_VIOLATION) {
+						throw $e;
+					}
 				}
 			}
 			$this->boardMapper->transferOwnership($previousOwner, $newOwner, $boardId);
@@ -702,10 +561,10 @@ class BoardService {
 				$this->assignedUsersMapper->remapAssignedUser($boardId, $previousOwner, $newOwner);
 				$this->cardMapper->remapCardOwner($boardId, $previousOwner, $newOwner);
 			}
-			\OC::$server->getDatabaseConnection()->commit();
+			$this->connection->commit();
 			return $this->boardMapper->find($boardId);
 		} catch (\Throwable $e) {
-			\OC::$server->getDatabaseConnection()->rollBack();
+			$this->connection->rollBack();
 			throw $e;
 		}
 	}
@@ -719,6 +578,143 @@ class BoardService {
 		}
 	}
 
+	/**
+	 * @param $id
+	 * @return Board
+	 * @throws DoesNotExistException
+	 * @throws NoPermissionException
+	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
+	 * @throws BadRequestException
+	 */
+	public function export($id) : Board {
+		if (is_numeric($id) === false) {
+			throw new BadRequestException('board id must be a number');
+		}
+
+		$this->permissionService->checkPermission($this->boardMapper, $id, Acl::PERMISSION_READ);
+		$board = $this->boardMapper->find((int)$id);
+		$this->enrichWithCards($board);
+		$this->enrichWithLabels($board);
+
+		return $board;
+	}
+
+	/** @param Board[] $boards */
+	private function enrichBoards(array $boards, bool $fullDetails = true): array {
+		$result = [];
+		foreach ($boards as $board) {
+			// FIXME The enrichment in here could make use of combined queries
+			$this->boardMapper->mapOwner($board);
+			if ($board->getAcl() !== null) {
+				foreach ($board->getAcl() as &$acl) {
+					$this->boardMapper->mapAcl($acl);
+				}
+			}
+
+			$permissions = $this->permissionService->matchPermissions($board);
+			$board->setPermissions([
+				'PERMISSION_READ' => $permissions[Acl::PERMISSION_READ] ?? false,
+				'PERMISSION_EDIT' => $permissions[Acl::PERMISSION_EDIT] ?? false,
+				'PERMISSION_MANAGE' => $permissions[Acl::PERMISSION_MANAGE] ?? false,
+				'PERMISSION_SHARE' => $permissions[Acl::PERMISSION_SHARE] ?? false
+			]);
+
+			if ($fullDetails) {
+				$this->enrichWithStacks($board);
+				$this->enrichWithLabels($board);
+				$this->enrichWithUsers($board);
+				$this->enrichWithBoardSettings($board);
+				$this->enrichWithActiveSessions($board);
+			}
+
+			// Cache for further usage
+			if ($fullDetails) {
+				$this->boardsCacheFull[$board->getId()] = $board;
+			} else {
+				$this->boardsCachePartial[$board->getId()] = $board;
+			}
+		}
+
+		return $boards;
+	}
+
+	private function cloneCards(Board $board, Board $newBoard, bool $withAssignments = false, bool $withLabels = false, bool $withDueDate = false, bool $moveCardsToLeftStack = false, bool $restoreArchivedCards = false): void {
+		$stacks = $this->stackMapper->findAll($board->getId());
+		$newStacks = $this->stackMapper->findAll($newBoard->getId());
+
+		$stackSorter = function (Stack $a, Stack $b) {
+			return $a->getOrder() - $b->getOrder();
+		};
+		usort($stacks, $stackSorter);
+		usort($newStacks, $stackSorter);
+
+		$i = 0;
+		foreach ($stacks as $stack) {
+			$cards = $this->cardMapper->findAll($stack->getId());
+			$archivedCards = $this->cardMapper->findAllArchived($stack->getId());
+
+			/** @var Card[] $cards */
+			$cards = array_merge($cards, $archivedCards);
+
+			foreach ($cards as $card) {
+				$targetStackId = $moveCardsToLeftStack ? $newStacks[0]->getId() : $newStacks[$i]->getId();
+
+				// Create a cloned card.
+				// Done with setters as only fields set via setters get written to db
+				$newCard = new Card();
+				$newCard->setTitle($card->getTitle());
+				$newCard->setDescription($card->getDescription());
+				$newCard->setStackId($targetStackId);
+				$newCard->setType($card->getType());
+				$newCard->setOwner($card->getOwner());
+				$newCard->setOrder($card->getOrder());
+				$newCard->setDuedate($withDueDate ? $card->getDuedate() : null);
+				$newCard->setArchived($restoreArchivedCards ? false : $card->getArchived());
+				$newCard->setStackId($targetStackId);
+
+				// Persist the cloned card.
+				$newCard = $this->cardMapper->insert($newCard);
+
+
+				// Copy labels.
+				if ($withLabels) {
+					$labels = $this->labelMapper->findAssignedLabelsForCard($card->getId());
+					$newLabels = $this->labelMapper->findAll($newBoard->getId());
+					$newLabelTitles = [];
+					foreach ($newLabels as $label) {
+						$newLabelTitles[$label->getTitle()] = $label;
+					}
+
+					foreach ($labels as $label) {
+						$newLabelId = $newLabelTitles[$label->getTitle()]?->getId() ?? null;
+						if ($newLabelId) {
+							$this->cardMapper->assignLabel($newCard->getId(), $newLabelId);
+						}
+					}
+				}
+
+
+				// Copy assignments.
+				if ($withAssignments) {
+					$assignments = $this->assignedUsersMapper->findAll($card->getId());
+
+					foreach ($assignments as $assignment) {
+						$this->assignmentService->assignUser($newCard->getId(), $assignment->getParticipant(), $assignment->getType());
+					}
+				}
+
+				// Known limitation: Currently we do not copy attachments or comments
+
+				// Copied from CardService because CardService cannot be injected due to cyclic dependencies.
+				$this->activityManager->triggerEvent(ActivityManager::DECK_OBJECT_CARD, $card, ActivityManager::SUBJECT_CARD_CREATE);
+				$this->changeHelper->cardChanged($card->getId(), false);
+				$this->eventDispatcher->dispatchTyped(new CardCreatedEvent($card));
+			}
+
+			$i++;
+		}
+	}
+
 	private function enrichWithStacks($board, $since = -1) {
 		$stacks = $this->stackMapper->findAll($board->getId(), null, null, $since);
 
@@ -741,20 +737,12 @@ class BoardService {
 
 	private function enrichWithUsers($board, $since = -1) {
 		$boardUsers = $this->permissionService->findUsers($board->getId());
-		if (\count($boardUsers) === 0) {
+		if ($boardUsers === null || \count($boardUsers) === 0) {
 			return;
 		}
 		$board->setUsers(array_values($boardUsers));
 	}
 
-	public function getBoardUrl($endpoint) {
-		return $this->urlGenerator->linkToRouteAbsolute('deck.page.index') . '#' . $endpoint;
-	}
-
-	private function clearBoardsCache() {
-		$this->boardsCache = null;
-	}
-
 	/**
 	 * Clean a given board data from the Cache
 	 */
@@ -763,6 +751,26 @@ class BoardService {
 		$boardOwnerId = $board->getOwner();
 
 		$this->boardMapper->flushCache($boardId, $boardOwnerId);
-		unset($this->boardsCache[$boardId]);
+		unset($this->boardsCacheFull[$boardId]);
+		unset($this->boardsCachePartial[$boardId]);
+	}
+
+	private function enrichWithCards($board) {
+		$stacks = $this->stackMapper->findAll($board->getId());
+		foreach ($stacks as $stack) {
+			$cards = $this->cardMapper->findAllByStack($stack->getId());
+			$fullCards = [];
+			foreach ($cards as $card) {
+				$fullCard = $this->cardMapper->find($card->getId());
+				array_push($fullCards, $fullCard);
+			}
+			$stack->setCards($fullCards);
+		}
+
+		if (\count($stacks) === 0) {
+			return;
+		}
+
+		$board->setStacks($stacks);
 	}
 }
